import type { ShapeDrawerAfterEffectFunction, ShapeDrawerDestroyFunction, ShapeDrawerDrawFunction, ShapeDrawerInitFunction } from "./Types/ShapeDrawerFunctions";
import { Container } from "./Core/Container";
import type { CustomEventArgs } from "./Types/CustomEventArgs";
import type { CustomEventListener } from "./Types/CustomEventListener";
import type { IInteractor } from "./Core/Interfaces/IInteractor";
import type { ILoadParams } from "./Core/Interfaces/ILoadParams";
import type { IMovePathGenerator } from "./Core/Interfaces/IMovePathGenerator";
import type { IParticleMover } from "./Core/Interfaces/IParticlesMover";
import type { IParticleUpdater } from "./Core/Interfaces/IParticleUpdater";
import type { IPlugin } from "./Core/Interfaces/IPlugin";
import type { IShapeDrawer } from "./Core/Interfaces/IShapeDrawer";
import type { ISourceOptions } from "./Types/ISourceOptions";
import type { Particle } from "./Core/Particle";
import { Plugins } from "./Core/Utils/Plugins";
import type { SingleOrMultiple } from "./Types/SingleOrMultiple";
export declare class Engine {
    readonly plugins: Plugins;
    private readonly _configs;
    private readonly _domArray;
    private readonly _eventDispatcher;
    constructor();
    get configs(): Record<string, ISourceOptions>;
    addConfig(nameOrConfig: string | ISourceOptions, config?: ISourceOptions): void;
    addEventListener(type: string, listener: CustomEventListener): void;
    addInteractor(name: string, interactorInitializer: (container: Container) => IInteractor): Promise<void>;
    addMover(name: string, moverInitializer: (container: Container) => IParticleMover): Promise<void>;
    addParticleUpdater(name: string, updaterInitializer: (container: Container) => IParticleUpdater): Promise<void>;
    addPathGenerator(name: string, generator: IMovePathGenerator): Promise<void>;
    addPlugin(plugin: IPlugin): Promise<void>;
    addPreset(preset: string, options: ISourceOptions, override?: boolean): Promise<void>;
    addShape(shape: SingleOrMultiple<string>, drawer: IShapeDrawer | ShapeDrawerDrawFunction, init?: ShapeDrawerInitFunction, afterEffect?: ShapeDrawerAfterEffectFunction, destroy?: ShapeDrawerDestroyFunction): Promise<void>;
    dispatchEvent(type: string, args: CustomEventArgs): void;
    dom(): Container[];
    domItem(index: number): Container | undefined;
    load(params: ILoadParams): Promise<Container | undefined>;
    refresh(): Promise<void>;
    removeEventListener(type: string, listener: CustomEventListener): void;
    setOnClickHandler(callback: (e: Event, particles?: Particle[]) => void): void;
}
